package org.globus.transfer.reliable.service.test.client;

import junit.framework.TestCase;
import org.globus.gsi.GlobusCredential;
import org.globus.gsi.gssapi.GlobusGSSCredentialImpl;
import org.globus.rft.generated.RFTOptionsType;
import org.globus.wsrf.impl.timer.TimerManagerImpl;
import org.globus.transfer.reliable.service.test.TestConfig;
import org.globus.transfer.reliable.service.test.connection.TestUtil;
import org.globus.transfer.reliable.service.cache.ConnectionCacheConfiguration;
import org.globus.transfer.reliable.service.cache.ConnectionManager;
import org.globus.transfer.reliable.service.cache.ConnectionParameter;
import org.globus.transfer.reliable.service.client.DeleteClient;
import org.ietf.jgss.GSSCredential;
import commonj.timers.TimerManager;

public class DeleteClientTest extends TestCase {
    
    private TimerManager timerManager;
    private ConnectionManager connManager;
    private RFTOptionsType rftOptions;
    private DeleteClient client;
    private ConnectionParameter params;
    private String subject;
    private GSSCredential credential = null;
    
    protected void setUp() throws Exception {
        
        super.setUp();
                
        // setup the timerManager
        this.timerManager = new TimerManagerImpl();

        // setup the connectionManager
        ConnectionCacheConfiguration cacheConfig = new ConnectionCacheConfiguration();
        cacheConfig.setConnectionTimeout(5000);
        cacheConfig.setMaxNumberCachedFDs(10);
        cacheConfig.setSweeperInterval(1000);
        this.connManager =  ConnectionManager.createNewInstance(
            cacheConfig, timerManager);

        this.credential = new GlobusGSSCredentialImpl(
            GlobusCredential.getDefaultCredential(),
            GSSCredential.INITIATE_AND_ACCEPT);

        this.subject = TestConfig.subject;
        if (this.subject == null || this.subject.trim().equals("")) {
            this.subject = TestConfig.sourceSubject;
        }

        this.rftOptions = new RFTOptionsType();
        // create connection parameter objects for source and destination
        params = new ConnectionParameter(
            TestConfig.sourceHost, TestConfig.sourcePort,
            TestUtil.REMOTE_TEST_DIR, this.subject, rftOptions);

        // create a client
        this.client = new DeleteClient(params, credential, connManager);   
    }
    
    protected void tearDown() throws Exception {
        
        this.connManager.closeAllConnections();
        this.timerManager.stop();
    }

    public void testProcess() {
        
        try {
            TestUtil.createTestDir(params.getSourceHost(),
                params.getSourcePort(), subject, credential);
            
            this.client.process();
            if(TestUtil.removeDirIfExists(params.getSourceHost(),
                params.getSourcePort(), TestUtil.REMOTE_TEST_DIR,
                this.subject, this.credential)) {
                fail("file still existed after deletion");
            }
        } catch (Exception e) {
            fail("testProcess() failed: " + e);
        }
    }    
}
